#Intalio::SystemUtils
#Copyright (C) 2019 by Драпевски Intalio, Release 1.00

package Intalio::SystemUtils;

use Exporter qw( import );
our @EXPORT = qw( GetInstallerDir GetInstallerDirName GetFileList CopyFiles MakeChownOnDir MakeChmodOnDir );

use strict;
use FindBin;
use lib "$FindBin::RealBin/../";
use File::Find;
use File::Basename;
use File::Copy::Recursive qw( dircopy );
use Cwd qw(abs_path);
use ShellQuoted qw( EscapeWhiteCharacters );
use Intalio::PrimaryUtils;

sub GetInstallerDir {
    #Return abs path to the module direcotry,
    my($volume, $directories, $file) = File::Spec->splitpath(abs_path($0));

    return File::Spec->catdir($volume, $directories);
}

sub GetInstallerDirName {
    my @dirs = File::Spec->splitdir( GetInstallerDir() );
    return $dirs[-1];    #Get installer directory name (Extension name)
}


sub GetFileList {
    my($Path, $Mask) = @_;

    return () if ! -d $Path;
    
    return grep { -e $_ } glob EscapeWhiteCharacters(File::Spec->catdir($Path, $Mask));
}


sub CopyFiles {
    my($SourcePath, $DestinationPath) = @_;
    
    die "Source directory $SourcePath not exists\n" if ! -d $SourcePath;
    die "Destination directory $DestinationPath not exists\n" if ! -d $DestinationPath;

    
    dircopy(File::Spec->catdir($SourcePath, '*'), $DestinationPath) or die "Can't copy file: $!\n";

}

sub MakeChownOnDir {
    my($Dir, $NewOwner) = @_;

    $Dir = EscapeWhiteCharacters($Dir);

    my $Result = `chown -R $NewOwner $Dir 2>&1 1>/dev/null`;
    die("chown error: $Result\n") if $Result ne ''; #If something was sent to STDERR
}

sub MakeChmodOnDir {
    my($Dir, $NewPerm) = @_;

    $Dir = EscapeWhiteCharacters($Dir);

    my $Result = `chmod -R $NewPerm $Dir 2>&1 1>/dev/null`;
    die("chmod error: $Result\n") if $Result ne ''; #If something was sent to STDERR
}


sub RestartZimbra {
    if ( Intalio::PrimaryUtils::IsRunAsRoot() ) {
        system("su -l zimbra bash -c 'zmmailboxdctl restart'");
    } else {
        system("zmmailboxdctl restart");
    }
    

}


1;